Scratcher class

Scratcher widget which covers given child with scratchable overlay.

Inheritance

Constructors

Scratcher({Key? key, required Widget child, bool enabled = true, double? threshold, double brushSize = 25, ScratchAccuracy accuracy = ScratchAccuracy.high, Color color = Colors.black, Image? image, bool rebuildOnResize = true, dynamic onChange(double value)?, VoidCallback? onThreshold, VoidCallback? onScratchStart, VoidCallback? onScratchUpdate, VoidCallback? onScratchEnd})

Properties

accuracy → ScratchAccuracy
Determines how accurate the progress should be reported. Lower accuracy means higher performance.
final
brushSize → double
Size of the brush. The bigger it is the faster user can scratch the card.
final
child → Widget
Widget rendered under the scratch area.
final
color → Color
Color used to cover the child widget.
final
enabled → bool
Whether new scratches can be applied
final
hashCode → int
The hash code for this object.
no setterinherited
image → Image?
Image widget used to cover the child widget.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange → dynamic Function(double value)?
Callback called when new part of area is revealed (min 0.1% difference, or progress == 100).
final
onScratchEnd → VoidCallback?
Callback called when scratching ends
final
onScratchStart → VoidCallback?
Callback called when scratching starts
final
onScratchUpdate → VoidCallback?
Callback called during scratching
final
onThreshold → VoidCallback?
Callback called when threshold is reached.
final
rebuildOnResize → bool
Determines if the scratcher should rebuild itself when space constraints change (resize).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold → double?
Percentage level of scratch area which should be revealed to complete.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → ScratcherState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited